Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(810)

Unified Diff: webrtc/logging/rtc_event_log/rtc_event_log_parser.h

Issue 2745473003: Resolve cyclic dependency between audio network adaptor and event log api (Closed)
Patch Set: Revert "Activated checks for rtc_event_log_api" Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/logging/rtc_event_log/rtc_event_log.cc ('k') | webrtc/logging/rtc_event_log/rtc_event_log_parser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
index 1460a4ca8358d4c45720da7469dfd01443f55509..208389398117c6c5aea7329e16c5267d0abb9787 100644
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
@@ -136,11 +136,10 @@ class ParsedRtcEventLog {
BandwidthUsage* detector_state) const;
// Reads a audio network adaptation event to a (non-NULL)
// AudioNetworkAdaptor::EncoderRuntimeConfig struct. Only the fields that are
// stored in the protobuf will be written.
- void GetAudioNetworkAdaptation(
- size_t index,
- AudioNetworkAdaptor::EncoderRuntimeConfig* config) const;
+ void GetAudioNetworkAdaptation(size_t index,
+ AudioEncoderRuntimeConfig* config) const;
private:
std::vector<rtclog::Event> events_;
« no previous file with comments | « webrtc/logging/rtc_event_log/rtc_event_log.cc ('k') | webrtc/logging/rtc_event_log/rtc_event_log_parser.cc » ('j') | no next file with comments »
@@ -136,11 +136,10 @@ class ParsedRtcEventLog {
BandwidthUsage* detector_state) const;
// Reads a audio network adaptation event to a (non-NULL)
- // AudioNetworkAdaptor::EncoderRuntimeConfig struct. Only the fields that are
+ // AudioEncoderRuntimeConfig struct. Only the fields that are
// stored in the protobuf will be written.

Powered by Google App Engine
This is Rietveld 408576698